/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.bcel.generic;

/**
 * Thrown on internal errors. Extends RuntimeException so it hasn't to be declared in the throws clause every time.
 */
public class ClassGenException extends RuntimeException {

    private static final long serialVersionUID = 7247369755051242791L;

    public ClassGenException() {
    }

    public ClassGenException(final String s) {
        super(s);
    }

    public ClassGenException(final String s, final Throwable initCause) {
        super(s, initCause);
    }
}
